audtorch.utils
==============

Utility functions.

.. automodule:: audtorch.utils

flatten_list
------------

.. autofunction:: flatten_list

to_tuple
--------

.. autofunction:: to_tuple

energy
------

.. autofunction:: energy

power
-----

.. autofunction:: power

run_worker_threads
------------------

.. autofunction:: run_worker_threads
